@load base/frameworks/communication/
@load base/protocols/http/

# bro script record for idmef alerts
type IDMEFalert: record {
	ts : time;
	id : conn_id &optional;
	classification : string;
	fields : table[string] of string &optional;
	additional_data : table[string] of string &optional;
};
#event for sending an alert to a broccoli server transmitting them via prelude
global preludeAlert: event(a: IDMEFalert);

#the server node
redef Communication::nodes += {
	["broprelude"] = [$host = 127.0.0.1, $p= 47759/tcp, $class="prelude", $connect=T, $ssl=F, $retry = 10 secs]
};

# the set of alerts which could not be sent when they occured
# people may want to change the time lasting behaviour
global failoverAlerts: table[time] of IDMEFalert &redef &persistent;

# an example of a generic function to send an alert or save it in a failover set
function sendAlert(ts: time, id: conn_id, title: string, datas : table[string] of string)
{
	local alert : IDMEFalert;
	alert$ts = ts;
	alert$id = id;
	alert$classification = title;
	alert$fields = table();
	alert$fields["alert.analyzer(-1).name"] = "Bro";
	alert$additional_data = datas;
	if (Communication::nodes["broprelude"]$connected)
	{
		event preludeAlert(alert);
		for (a in failoverAlerts)
		{
			event preludeAlert(failoverAlerts[a]);
			delete failoverAlerts[a];
		}
	}
	else
	{
		failoverAlerts[alert$ts] = alert;
	}
}

# an example with a dummy alert
event http_reply(c: connection, version: string, code: count, reason: string)
{
	if (code >= 400)
	{
		local datas: table[string] of string = table();
		datas["code"] = fmt("%d", code);
		datas["version"] = version;
		sendAlert(network_time(), c$id, "Bad HTTP reply", datas);
	}
}

